#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : AI.  @by PyCharm
# @File         : tryblend_types
# @Time         : 2024/9/4 08:54
# @Author       : betterme
# @WeChat       : meutils
# @Software     : PyCharm
# @Description  : 


BASE_URL = "https://www.tryblend.ai/"
FEISHU_URL = "https://xchatllm.feishu.cn/sheets/Bmjtst2f6hfMqFttbhLcdfRJnNf?sheet=hxVlQw"
FEISHU_URL_VIP = "https://xchatllm.feishu.cn/sheets/Bmjtst2f6hfMqFttbhLcdfRJnNf?sheet=LYcY2c"

GPT_4O = [{"requestId":"4aee81b2-2379-4bd2-ae7a-99c9c6867c86","selectedModel":{"id":"openai:gpt-4o","active":True,"name":"GPT 4o","provider":"openai","maker":"openai","makerHumanName":"OpenAI","fallbackIcon":None,"providerModelId":"gpt-4o","info":{"description":"GPT-4o is OpenAI's most advanced multimodal model that’s faster and cheaper than GPT-4 Turbo with stronger vision capabilities.","fundationModel":"GPT-4","fundationModelMaker":"OpenAI","releaseDate":"2024","knowledgeCutoff":"October, 2023","context":"128000","predictionTimeSecond":None,"usableAsAssistant":True,"pricing":{"inputImagePrice":0.003,"inputPrice":5,"outputPrice":15,"inputPriceUnit":"1m tokens","outputPriceUnit":"1m tokens"},"inputType":["text","image"],"outputType":["text"],"type":["text","vision"],"keywords":["trending","vision"],"website":"https://openai.com/research/gpt-4","fallbackModel":None},"parameters":[{"name":"prompt","description":"The prompt to use for the request","parameterType":"directInput","defaultValue":""},{"name":"file","description":"Files to use as complimentary information for the prompt.","parameterType":"directInput","defaultValue":[],"fileOptions":[{"fileExtension":[".jpg",".jpeg",".webp",".png",".gif"],"fileExtensionName":"image","maxFileSize":20,"minFileCount":0,"maxFileCount":20},{"fileExtension":[".c",".cpp",".cs",".java",".py",".rb",".js",".ts",".tsx",".jsx",".php",".go",".swift",".kt",".scala",".rs",".lua",".pl",".sh",".bash",".ps1",".html",".css",".scss",".less",".json",".xml",".yaml",".yml",".md",".markdown",".txt",".rtf",".tex",".log",".xlsx",".pdf",".csv",".tsv",".ini",".cfg",".conf",".toml",".sql",".r",".m",".f",".f90",".vb",".bas",".ps",".asm"],"fileExtensionName":"text","maxFileSize":5,"minFileCount":0,"maxFileCount":10}]}]},"messages":[{"role":"user","content":[{"type":"text","text":"1"}]}],"sessionId":"bb06bb82-708e-4c98-b9db-3771d654195e","userMessageId":"4b1a58ac-55f9-4655-ab3e-1d7cff788b70","assistantMessageId":"4c7eb0ce-69b3-42d9-bf7c-3692f3c04e47"}]
GPT_4O_MINI = [{"requestId":"9146047d-387a-4894-b64a-879401a0bed0","selectedModel":{"id":"openai:gpt-4o-mini","active":True,"name":"GPT 4o Mini","provider":"openai","maker":"openai","makerHumanName":"OpenAI","fallbackIcon":None,"providerModelId":"gpt-4o-mini","info":{"description":"GPT-4o mini is OpenAI's most cost-efficient small model that’s smarter and cheaper than GPT-3.5 Turbo, and has vision capabilities.","fundationModel":"GPT-4","fundationModelMaker":"OpenAI","releaseDate":"2024","knowledgeCutoff":"October, 2023","context":"128000","predictionTimeSecond":None,"usableAsAssistant":True,"pricing":{"inputImagePrice":0.003,"inputPrice":0.15,"outputPrice":0.6,"inputPriceUnit":"1m tokens","outputPriceUnit":"1m tokens"},"inputType":["text","image"],"outputType":["text"],"type":["text","vision"],"keywords":["free","vision"],"website":"https://openai.com/research/gpt-4","fallbackModel":None},"parameters":[{"name":"prompt","description":"The prompt to use for the request","parameterType":"directInput","defaultValue":""},{"name":"file","description":"Files to use as complimentary information for the prompt.","parameterType":"directInput","defaultValue":[],"fileOptions":[{"fileExtension":[".jpg",".jpeg",".webp",".png",".gif"],"fileExtensionName":"image","maxFileSize":5,"minFileCount":0,"maxFileCount":20},{"fileExtension":[".c",".cpp",".cs",".java",".py",".rb",".js",".ts",".tsx",".jsx",".php",".go",".swift",".kt",".scala",".rs",".lua",".pl",".sh",".bash",".ps1",".html",".css",".scss",".less",".json",".xml",".yaml",".yml",".md",".markdown",".txt",".rtf",".tex",".log",".xlsx",".pdf",".csv",".tsv",".ini",".cfg",".conf",".toml",".sql",".r",".m",".f",".f90",".vb",".bas",".ps",".asm"],"fileExtensionName":"text","maxFileSize":5,"minFileCount":0,"maxFileCount":10}]}]},"messages":[{"role":"user","content":[{"type":"text","text":"1"}]}],"sessionId":"7f27c6b6-1e98-4bb4-9e90-6d68d759632e","userMessageId":"e63eadcf-6715-40a5-805f-ce9442c4518c","assistantMessageId":"ab0971c4-03fa-4c96-9932-b4019d1ded46"}]
CLAUDE_3_HAIKU = [{"requestId":"86ce06bd-f76c-4cc4-91af-062907091af9","selectedModel":{"id":"openrouter:anthropic/claude-3-haiku","active":True,"name":"Claude 3 Haiku","provider":"openrouter","maker":"anthropic","makerHumanName":"Anthropic","fallbackIcon":None,"providerModelId":"anthropic/claude-3-haiku","info":{"description":"Claude 3 Haiku is Anthropic's fastest and most compact model for near-instant responsiveness. Quick and accurate targeted performance.","fundationModel":None,"fundationModelMaker":None,"releaseDate":"March 4, 2024","knowledgeCutoff":None,"context":"200000","predictionTimeSecond":None,"usableAsAssistant":False,"pricing":{"inputImagePrice":0.0004,"inputPrice":0.25,"outputPrice":1.25,"inputPriceUnit":"1m tokens","outputPriceUnit":"1m tokens"},"inputType":["text","image"],"outputType":["text"],"type":["text","vision"],"keywords":["free","vision"],"website":"https://www.anthropic.com/news/claude-3-family","fallbackModel":None},"parameters":[{"name":"prompt","description":"The prompt to use for the request","parameterType":"directInput","defaultValue":""},{"name":"file","description":"Files to use as complimentary information for the prompt.","parameterType":"directInput","defaultValue":[],"fileOptions":[{"fileExtension":[".jpg",".jpeg",".webp",".png",".gif"],"fileExtensionName":"image","maxFileSize":5,"minFileCount":0,"maxFileCount":20},{"fileExtension":[".c",".cpp",".cs",".java",".py",".rb",".js",".ts",".tsx",".jsx",".php",".go",".swift",".kt",".scala",".rs",".lua",".pl",".sh",".bash",".ps1",".html",".css",".scss",".less",".json",".xml",".yaml",".yml",".md",".markdown",".txt",".rtf",".tex",".log",".xlsx",".pdf",".csv",".tsv",".ini",".cfg",".conf",".toml",".sql",".r",".m",".f",".f90",".vb",".bas",".ps",".asm"],"fileExtensionName":"text","maxFileSize":5,"minFileCount":0,"maxFileCount":10}]}]},"messages":[{"role":"user","content":[{"type":"text","text":"1"}]},{"role":"assistant","content":[{"type":"text","text":"Hello! It looks like you entered \"1.\" How can I assist you today? If you have a question or need information, feel free to let me know!"}]},{"role":"user","content":[{"type":"text","text":"1"}]}],"sessionId":"bb06bb82-708e-4c98-b9db-3771d654195e","userMessageId":"313e734a-fd15-404a-8132-92548aa783b5","assistantMessageId":"5610ede0-3da9-4c0e-bfab-c83fb282312f"}]
CLAUDE_3_SONNET = [{"requestId":"00e9b684-29c1-42b4-b2c5-2d7eb6c0be25","selectedModel":{"id":"openrouter:anthropic/claude-3-sonnet","active":True,"name":"Claude 3 Sonnet","provider":"openrouter","maker":"anthropic","makerHumanName":"Anthropic","fallbackIcon":None,"providerModelId":"anthropic/claude-3-sonnet","info":{"description":"Claude 3 Sonnet is an ideal balance of intelligence and speed for enterprise workloads. Maximum utility at a lower price, dependable, balanced for scaled deployments.","fundationModel":None,"fundationModelMaker":None,"releaseDate":"March 4, 2024","knowledgeCutoff":None,"context":"200000","predictionTimeSecond":None,"usableAsAssistant":False,"pricing":{"inputImagePrice":0.0048,"inputPrice":3,"outputPrice":15,"inputPriceUnit":"1m tokens","outputPriceUnit":"1m tokens"},"inputType":["text","image"],"outputType":["text"],"type":["text","vision"],"keywords":["vision"],"website":"https://www.anthropic.com/news/claude-3-family","fallbackModel":None},"parameters":[{"name":"prompt","description":"The prompt to use for the request","parameterType":"directInput","defaultValue":""},{"name":"file","description":"Files to use as complimentary information for the prompt.","parameterType":"directInput","defaultValue":[],"fileOptions":[{"fileExtension":[".jpg",".jpeg",".webp",".png",".gif"],"fileExtensionName":"image","maxFileSize":5,"minFileCount":0,"maxFileCount":20},{"fileExtension":[".c",".cpp",".cs",".java",".py",".rb",".js",".ts",".tsx",".jsx",".php",".go",".swift",".kt",".scala",".rs",".lua",".pl",".sh",".bash",".ps1",".html",".css",".scss",".less",".json",".xml",".yaml",".yml",".md",".markdown",".txt",".rtf",".tex",".log",".xlsx",".pdf",".csv",".tsv",".ini",".cfg",".conf",".toml",".sql",".r",".m",".f",".f90",".vb",".bas",".ps",".asm"],"fileExtensionName":"text","maxFileSize":5,"minFileCount":0,"maxFileCount":10}]}]},"messages":[{"role":"user","content":[{"type":"text","text":"1"}]}],"sessionId":"ea188159-85ce-49da-8bf3-c8364f497e1a","userMessageId":"ab21e0dd-993d-44f0-b7be-a80baf2460f1","assistantMessageId":"cf5bbf51-1c8d-4465-a35f-0cf5ced9e7ef"}]
CLAUDE_3_OPUS = [{"requestId":"ee6e9a61-4546-499a-aa00-03115a088206","selectedModel":{"id":"openrouter:anthropic/claude-3-opus","active":True,"name":"Claude 3 Opus","provider":"openrouter","maker":"anthropic","makerHumanName":"Anthropic","fallbackIcon":None,"providerModelId":"anthropic/claude-3-opus","info":{"description":"Claude 3 Opus is Anthropic's most powerful model for highly complex tasks. It boasts top-level performance, intelligence, fluency, and understanding. It beats GPT-4 on most benchmarks","fundationModel":None,"fundationModelMaker":None,"releaseDate":"March 4, 2024","knowledgeCutoff":None,"context":"200000","predictionTimeSecond":None,"usableAsAssistant":False,"pricing":{"inputImagePrice":0.024,"inputPrice":15,"outputPrice":75,"inputPriceUnit":"1m tokens","outputPriceUnit":"1m tokens"},"inputType":["text","image"],"outputType":["text"],"type":["text","vision"],"keywords":["vision"],"website":"https://www.anthropic.com/news/claude-3-family","fallbackModel":None},"parameters":[{"name":"prompt","description":"The prompt to use for the request","parameterType":"directInput","defaultValue":""},{"name":"file","description":"Files to use as complimentary information for the prompt.","parameterType":"directInput","defaultValue":[],"fileOptions":[{"fileExtension":[".jpg",".jpeg",".webp",".png",".gif"],"fileExtensionName":"image","maxFileSize":5,"minFileCount":0,"maxFileCount":20},{"fileExtension":[".c",".cpp",".cs",".java",".py",".rb",".js",".ts",".tsx",".jsx",".php",".go",".swift",".kt",".scala",".rs",".lua",".pl",".sh",".bash",".ps1",".html",".css",".scss",".less",".json",".xml",".yaml",".yml",".md",".markdown",".txt",".rtf",".tex",".log",".xlsx",".pdf",".csv",".tsv",".ini",".cfg",".conf",".toml",".sql",".r",".m",".f",".f90",".vb",".bas",".ps",".asm"],"fileExtensionName":"text","maxFileSize":5,"minFileCount":0,"maxFileCount":10}]}]},"messages":[{"role":"user","content":[{"type":"text","text":"1"}]}],"sessionId":"f112a636-bda4-47e1-9e35-8fea5a12cbf3","userMessageId":"1a80572b-c7cb-4407-a301-ba8471cdc23c","assistantMessageId":"d2e275af-4648-4d60-a292-38766f5a0425"}]
CLAUDE_35_SONNET = [{"requestId":"e1da0fc4-ec34-4784-a336-0dce0f7152d1","selectedModel":{"id":"openrouter:anthropic/claude-3.5-sonnet","active":True,"name":"Claude 3.5 Sonnet","provider":"openrouter","maker":"anthropic","makerHumanName":"Anthropic","fallbackIcon":None,"providerModelId":"anthropic/claude-3.5-sonnet","info":{"description":"Claude 3.5 Sonnet delivers better-than-Opus capabilities, faster-than-Sonnet speeds, at the same Sonnet prices. Sonnet is particularly good at: Coding: Autonomously writes, edits, and runs code with reasoning and troubleshooting Data science: Augments human data science expertise; navigates unstructured data while using multiple tools for insights Visual processing: excelling at interpreting charts, graphs, and images, accurately transcribing text to derive insights beyond just the text alone Agentic tasks: exceptional tool use, making it great at agentic tasks (i.e. complex, multi-step problem solving tasks that require engaging with other systems)","fundationModel":None,"fundationModelMaker":None,"releaseDate":"2024","knowledgeCutoff":"2024","context":"200000","predictionTimeSecond":None,"usableAsAssistant":False,"pricing":{"inputImagePrice":0.0048,"inputPrice":3,"outputPrice":15,"inputPriceUnit":"1m tokens","outputPriceUnit":"1m tokens"},"inputType":["text","image"],"outputType":["text"],"type":["text","vision"],"keywords":["trending","vision"],"website":"https://www.anthropic.com/news/claude-3-family","fallbackModel":None},"parameters":[{"name":"prompt","description":"The prompt to use for the request","parameterType":"directInput","defaultValue":""},{"name":"file","description":"Files to use as complimentary information for the prompt.","parameterType":"directInput","defaultValue":[],"fileOptions":[{"fileExtension":[".jpg",".jpeg",".webp",".png",".gif"],"fileExtensionName":"image","maxFileSize":5,"minFileCount":0,"maxFileCount":20},{"fileExtension":[".c",".cpp",".cs",".java",".py",".rb",".js",".ts",".tsx",".jsx",".php",".go",".swift",".kt",".scala",".rs",".lua",".pl",".sh",".bash",".ps1",".html",".css",".scss",".less",".json",".xml",".yaml",".yml",".md",".markdown",".txt",".rtf",".tex",".log",".xlsx",".pdf",".csv",".tsv",".ini",".cfg",".conf",".toml",".sql",".r",".m",".f",".f90",".vb",".bas",".ps",".asm"],"fileExtensionName":"text","maxFileSize":5,"minFileCount":0,"maxFileCount":10}]}]},"messages":[{"role":"user","content":[{"type":"text","text":"1"}]}],"sessionId":"ea24b58e-6132-45ab-a46e-b8ff7bd235e2","userMessageId":"74f40c8a-bc94-4fb4-96cc-4b118309cf61","assistantMessageId":"79f48170-71ad-45bd-b895-a1dc4a17ffa3"}]
PERPLEXITY_SONAR_SMALL = [{"requestId":"a3338192-e46f-4ae3-83b2-8e428935c8ea","selectedModel":{"id":"perplexity/llama-3.1-sonar-small-128k-online","active":True,"name":"Perplexity Sonar Small","provider":"perplexity","maker":"perplexity","makerHumanName":"Perplexity","fallbackIcon":None,"providerModelId":"llama-3.1-sonar-small-128k-online","info":{"description":"The smaller, internet-connected chat model by Perplexity Labs, based on Llama 3.1. The online models are focused on delivering helpful, up-to-date, and factual responses.","fundationModel":"LLama 3 8B","fundationModelMaker":"Meta","releaseDate":"August 2024","knowledgeCutoff":"Today","context":"128000","predictionTimeSecond":None,"usableAsAssistant":False,"pricing":{"inputImagePrice":None,"inputPrice":0.2,"outputPrice":0.2,"inputPriceUnit":"request","outputPriceUnit":"1m tokens"},"inputType":["text"],"outputType":["text"],"type":["text"],"keywords":["free","online search"],"website":"https://blog.perplexity.ai/blog/introducing-pplx-online-llms","fallbackModel":None},"parameters":[{"name":"prompt","description":"The prompt to use for the request","parameterType":"directInput","defaultValue":""},{"name":"file","description":"Files to use as complimentary information for the prompt.","parameterType":"directInput","defaultValue":[],"fileOptions":[{"fileExtension":[".c",".cpp",".cs",".java",".py",".rb",".js",".ts",".tsx",".jsx",".php",".go",".swift",".kt",".scala",".rs",".lua",".pl",".sh",".bash",".ps1",".html",".css",".scss",".less",".json",".xml",".yaml",".yml",".md",".markdown",".txt",".rtf",".tex",".log",".xlsx",".pdf",".csv",".tsv",".ini",".cfg",".conf",".toml",".sql",".r",".m",".f",".f90",".vb",".bas",".ps",".asm"],"fileExtensionName":"text","maxFileSize":5,"minFileCount":0,"maxFileCount":10}]}]},"messages":[{"role":"user","content":[{"type":"text","text":"1"}]},{"role":"assistant","content":[{"type":"text","text":"It appears you might have entered a number without providing context. Here are a few possible interpretations:\n\n1. **Numerical Value**: If you simply entered \"1\" as a number, it could represent various things depending on the context, such as a quantity, a ranking, or a specific item in a list.\n2. **Question or Request**: If you are asking for information or assistance related to the number \"1,\" please provide more details so I can help you better.\n3. **List or Sequence**: If you are starting a list or sequence, \"1\" would be the first item.\n\nTo provide a more accurate response, could you please clarify what you are looking for?"}]},{"role":"user","content":[{"type":"text","text":"1"}]}],"sessionId":"430642e3-05e7-42cf-ac09-860202456dd5","userMessageId":"89a39d94-2d7b-4c89-b588-721d93a18bb6","assistantMessageId":"085f5380-5054-4260-be0f-2333486156af"}]
PERPLEXITY_SONAR_LARGE = [{"requestId":"ff8e920c-6ec3-4d26-8e47-9c0357bd38d4","selectedModel":{"id":"perplexity/llama-3.1-sonar-large-128k-online","active":True,"name":"Perplexity Sonar Large","provider":"perplexity","maker":"perplexity","makerHumanName":"Perplexity","fallbackIcon":None,"providerModelId":"llama-3.1-sonar-large-128k-online","info":{"description":"The larger, internet-connected chat model by Perplexity Labs, based on Llama 3.1. The online models are focused on delivering helpful, up-to-date, and factual responses.","fundationModel":"LLama 3 70B","fundationModelMaker":"Meta","releaseDate":"August 2024","knowledgeCutoff":"Today","context":"128000","predictionTimeSecond":None,"usableAsAssistant":False,"pricing":{"inputImagePrice":None,"inputPrice":1,"outputPrice":1,"inputPriceUnit":"request","outputPriceUnit":"1m tokens"},"inputType":["text"],"outputType":["text"],"type":["text"],"keywords":["online search"],"website":"https://blog.perplexity.ai/blog/introducing-pplx-online-llms","fallbackModel":None},"parameters":[{"name":"prompt","description":"The prompt to use for the request","parameterType":"directInput","defaultValue":""},{"name":"file","description":"Files to use as complimentary information for the prompt.","parameterType":"directInput","defaultValue":[],"fileOptions":[{"fileExtension":[".c",".cpp",".cs",".java",".py",".rb",".js",".ts",".tsx",".jsx",".php",".go",".swift",".kt",".scala",".rs",".lua",".pl",".sh",".bash",".ps1",".html",".css",".scss",".less",".json",".xml",".yaml",".yml",".md",".markdown",".txt",".rtf",".tex",".log",".xlsx",".pdf",".csv",".tsv",".ini",".cfg",".conf",".toml",".sql",".r",".m",".f",".f90",".vb",".bas",".ps",".asm"],"fileExtensionName":"text","maxFileSize":5,"minFileCount":0,"maxFileCount":10}]}]},"messages":[{"role":"user","content":[{"type":"text","text":"1"}]}],"sessionId":"430642e3-05e7-42cf-ac09-860202456dd5","userMessageId":"09d1272e-935d-4427-ac79-a206c1ed03bb","assistantMessageId":"65378f38-082c-4ab6-ab40-8a39c741e741"}]
PERPLEXITY_SONAR_HUGE = [{"requestId":"daef312d-818d-4e90-827e-7dd388df2464","selectedModel":{"id":"perplexity/llama-3.1-sonar-huge-128k-online","active":True,"name":"Perplexity Sonar Huge","provider":"perplexity","maker":"perplexity","makerHumanName":"Perplexity","fallbackIcon":None,"providerModelId":"llama-3.1-sonar-huge-128k-online","info":{"description":"The larger, internet-connected chat model by Perplexity Labs, based on Llama 3.1. The online models are focused on delivering helpful, up-to-date, and factual responses.","fundationModel":"LLama 3 405B","fundationModelMaker":"Meta","releaseDate":"August 2024","knowledgeCutoff":"Today","context":"128000","predictionTimeSecond":None,"usableAsAssistant":False,"pricing":{"inputImagePrice":None,"inputPrice":5,"outputPrice":5,"inputPriceUnit":"request","outputPriceUnit":"1m tokens"},"inputType":["text"],"outputType":["text"],"type":["text"],"keywords":["trending","online search"],"website":"https://blog.perplexity.ai/blog/introducing-pplx-online-llms","fallbackModel":None},"parameters":[{"name":"prompt","description":"The prompt to use for the request","parameterType":"directInput","defaultValue":""},{"name":"file","description":"Files to use as complimentary information for the prompt.","parameterType":"directInput","defaultValue":[],"fileOptions":[{"fileExtension":[".c",".cpp",".cs",".java",".py",".rb",".js",".ts",".tsx",".jsx",".php",".go",".swift",".kt",".scala",".rs",".lua",".pl",".sh",".bash",".ps1",".html",".css",".scss",".less",".json",".xml",".yaml",".yml",".md",".markdown",".txt",".rtf",".tex",".log",".xlsx",".pdf",".csv",".tsv",".ini",".cfg",".conf",".toml",".sql",".r",".m",".f",".f90",".vb",".bas",".ps",".asm"],"fileExtensionName":"text","maxFileSize":5,"minFileCount":0,"maxFileCount":10}]}]},"messages":[{"role":"user","content":[{"type":"text","text":"11"}]}],"sessionId":"b9cc2133-5da9-4e28-934d-21877246a830","userMessageId":"af132989-38ce-4375-9b1c-512c55d28fba","assistantMessageId":"617bbeb1-eb61-4e85-b4c9-c85f614ceca6"}]
# 画画
FLUX_SCHNELL = {"userMessage":{"id":"81439612-aa86-43a3-a127-6fa2a89b7a37","parentId":"db331b85-ce87-4950-9574-baef444511e6","role":"user","content":"a dog","createdAt":"2024-09-06T06:24:55.571Z","modelId":"falai:fal-ai/flux/schnell","info":{"type":"userTextMessage","isSaved":True},"status":{"isLoading":False},"files":[],"parameters":{}},"selectedModel":{"id":"falai:fal-ai/flux/schnell","active":True,"name":"Flux.1 Schnell","provider":"falai","maker":"black forest labs","makerHumanName":"Black Forest Labs","fallbackIcon":None,"providerModelId":"fal-ai/flux/schnell","info":{"description":"The smallest, cheapest and fastest model of the suite of text-to-image models that define a new state-of-the-art in image detail, prompt adherence, style diversity, and scene complexity for text-to-image synthesis.","fundationModel":None,"fundationModelMaker":None,"releaseDate":"August 1, 2024","knowledgeCutoff":None,"context":None,"predictionTimeSecond":None,"usableAsAssistant":False,"pricing":{"inputImagePrice":0,"inputPrice":0,"outputPrice":0.003,"inputPriceUnit":"image","outputPriceUnit":"megapixel"},"inputType":["text"],"outputType":["image"],"type":["image"],"keywords":["free"],"website":"https://blackforestlabs.ai/announcing-black-forest-labs/?ref=blog.fal.ai","fallbackModel":None},"parameters":[{"name":"prompt","description":"The prompt to use for the request","parameterType":"directInput","defaultValue":""},{"name":"file","description":"Files to use as complimentary information for the prompt.","parameterType":"directInput","defaultValue":[],"fileOptions":[{"fileExtension":[".c",".cpp",".cs",".java",".py",".rb",".js",".ts",".tsx",".jsx",".php",".go",".swift",".kt",".scala",".rs",".lua",".pl",".sh",".bash",".ps1",".html",".css",".scss",".less",".json",".xml",".yaml",".yml",".md",".markdown",".txt",".rtf",".tex",".log",".xlsx",".pdf",".csv",".tsv",".ini",".cfg",".conf",".toml",".sql",".r",".m",".f",".f90",".vb",".bas",".ps",".asm"],"fileExtensionName":"text","maxFileSize":5,"minFileCount":0,"maxFileCount":10}]}]},"sessionId":"8f8500aa-0c8c-411c-b27f-0d9febd7c498","userMessageId":"81439612-aa86-43a3-a127-6fa2a89b7a37","assistantMessageId":"5a060fc3-f9d5-4844-baf3-ae5d8715d0b4","requestId":"61a762e2-4781-4c14-bcb0-7cd481e00820"}
FLUX_PRO = {"userMessage":{"id":"67d8d521-955e-4664-b07b-3c4ecf82c214","parentId":None,"role":"user","content":"11","createdAt":"2024-09-06T06:31:31.047Z","modelId":"falai:fal-ai/flux/pro","info":{"type":"userTextMessage","isSaved":True},"status":{"isLoading":False},"files":[],"parameters":{}},"selectedModel":{"id":"falai:fal-ai/flux/pro","active":True,"name":"Flux.1 Pro","provider":"falai","maker":"black forest labs","makerHumanName":"Black Forest Labs","fallbackIcon":None,"providerModelId":"fal-ai/flux-pro","info":{"description":"The largest model of the suite of text-to-image models that define a new state-of-the-art in image detail, prompt adherence, style diversity, and scene complexity for text-to-image synthesis.","fundationModel":None,"fundationModelMaker":None,"releaseDate":"August 1, 2024","knowledgeCutoff":None,"context":None,"predictionTimeSecond":None,"usableAsAssistant":False,"pricing":{"inputImagePrice":0,"inputPrice":0,"outputPrice":0.05,"inputPriceUnit":"image","outputPriceUnit":"megapixel"},"inputType":["text"],"outputType":["image"],"type":["image"],"keywords":["trending"],"website":"https://blackforestlabs.ai/announcing-black-forest-labs/?ref=blog.fal.ai","fallbackModel":None},"parameters":[{"name":"prompt","description":"The prompt to use for the request","parameterType":"directInput","defaultValue":""},{"name":"file","description":"Files to use as complimentary information for the prompt.","parameterType":"directInput","defaultValue":[],"fileOptions":[{"fileExtension":[".c",".cpp",".cs",".java",".py",".rb",".js",".ts",".tsx",".jsx",".php",".go",".swift",".kt",".scala",".rs",".lua",".pl",".sh",".bash",".ps1",".html",".css",".scss",".less",".json",".xml",".yaml",".yml",".md",".markdown",".txt",".rtf",".tex",".log",".xlsx",".pdf",".csv",".tsv",".ini",".cfg",".conf",".toml",".sql",".r",".m",".f",".f90",".vb",".bas",".ps",".asm"],"fileExtensionName":"text","maxFileSize":5,"minFileCount":0,"maxFileCount":10}]}]},"sessionId":"c1121f53-e40c-4b9e-9321-d54bfe7af39e","userMessageId":"67d8d521-955e-4664-b07b-3c4ecf82c214","assistantMessageId":"02aee5af-474c-496b-b63d-79e86e540ef6","requestId":"7a10bc5c-90c4-494d-9834-17dbab6c3661"}
DALL_E_3 = {"userMessage":{"id":"1753c29d-8a4c-41c7-b389-3e290aab7937","parentId":"02aee5af-474c-496b-b63d-79e86e540ef6","role":"user","content":"1","createdAt":"2024-09-06T06:32:12.717Z","modelId":"openai:dall-e-3","info":{"type":"userTextMessage","isSaved":True},"status":{"isLoading":False},"files":[],"parameters":{}},"selectedModel":{"id":"openai:dall-e-3","active":True,"name":"DALL·E 3","provider":"openai","maker":"openai","makerHumanName":"OpenAI","fallbackIcon":None,"providerModelId":"dall-e-3","info":{"description":"no description","fundationModel":None,"fundationModelMaker":None,"releaseDate":"2023","knowledgeCutoff":None,"context":None,"predictionTimeSecond":25,"usableAsAssistant":False,"pricing":{"inputImagePrice":0,"inputPrice":0,"outputPrice":0.04,"inputPriceUnit":"image","outputPriceUnit":"image"},"inputType":["text"],"outputType":["image"],"type":["image"],"keywords":[],"website":None,"fallbackModel":None},"parameters":[{"name":"prompt","description":"The prompt to use for the request","parameterType":"directInput","defaultValue":""},{"name":"file","description":"Files to use as complimentary information for the prompt.","parameterType":"directInput","defaultValue":[],"fileOptions":[{"fileExtension":[".c",".cpp",".cs",".java",".py",".rb",".js",".ts",".tsx",".jsx",".php",".go",".swift",".kt",".scala",".rs",".lua",".pl",".sh",".bash",".ps1",".html",".css",".scss",".less",".json",".xml",".yaml",".yml",".md",".markdown",".txt",".rtf",".tex",".log",".xlsx",".pdf",".csv",".tsv",".ini",".cfg",".conf",".toml",".sql",".r",".m",".f",".f90",".vb",".bas",".ps",".asm"],"fileExtensionName":"text","maxFileSize":5,"minFileCount":0,"maxFileCount":10}]}]},"sessionId":"c1121f53-e40c-4b9e-9321-d54bfe7af39e","userMessageId":"1753c29d-8a4c-41c7-b389-3e290aab7937","assistantMessageId":"91d4b7d7-065f-400c-8b72-634709e958b7","requestId":"07a4c955-ccef-4c97-ac92-ba5a6d5cc17d"}
# {
#     "files": [
#         {
#             "id": "a8009269-7ac8-409e-b711-b21081ca42aa",
#             "createdAt": "2024-09-06T06:31:49.758Z",
#             "name": "43fa234cc8244815979580895525f451_file.jpg",
#             "extension": "jpg",
#             "mediaType": "image",
#             "type": "jpg",
#             "uploadThingType": "url",
#             "size": 464801,
#             "url": "https://utfs.io/f/2878c70b-7fa9-4996-a3f1-d2cc9a200907-djxsni.jpg",
#         }
#     ]
# }

CHECK_PAYLOAD=[{"id":"9e8e7911-4924-47f7-9a34-c9e846c658a1","createdAt":"$D2024-09-12T09:23:24.194Z","parentId":None,"sessionId":"45be1b8a-ea37-43f5-ab80-7d53e2e7edbd","userId":"7b4943cf-78da-45bc-a38f-427a35aa3b89","role":"user","content":"1","modelId":"openai:gpt-4o-mini","info":{"type":"userTextMessage"},"status":{"isLoading":False},"files":[]}]
if __name__ == '__main__':
    import json_repair

    # print("net".startswith(("perplexity", "net")))

    print(list(GPT_4O[0]['selectedModel']))
